Attotree
==================================================================================


Introduction
------------

Rapid estimation of phylogenetic tree direclty from FASTA files in the style of
`Mashtree <https://github.com/lskatz/mashtree>`_.


Dependencies
------------

* `Mash <https://github.com/marbl/Mash>`_ (installation: ``conda install -c bioconda mash``)
* `QuickTree <https://github.com/khowe/quicktree>`_ (installation: ``conda install -c bioconda quicktree``)


Quick example
-------------

.. code-block:: bash

    git clone https://github.com/karel-brinda/attotree
    cd attotree
    ./attotree/attotree.py tests/*.fa


Issues
------

Please use `Github issues <https://github.com/karel-brinda/attotree/issues>`_.


Changelog
---------

See `Releases <https://github.com/karel-brinda/attotree/releases>`_.


Licence
-------

`MIT <https://github.com/karel-brinda/attotree/blob/master/LICENSE.txt>`_


Authors
-------

`Karel Brinda <http://brinda.eu>`_ <karel.brinda@inria.fr>

